package com.persagy.fm.sop.controller;

import com.alibaba.fastjson.JSONObject;
import com.persagy.fm.common.response.FmResponseMsg;
import com.persagy.fm.common.response.FmResponseUtil;
import com.persagy.fm.sop.model.dto.RefSopInfo;
import com.persagy.fm.sop.model.vo.QuerySopReferenceVo;
import com.persagy.fm.sop.model.vo.SaveSopEditVo;
import com.persagy.fm.sop.model.vo.SaveSopVo;
import com.persagy.fm.sop.model.vo.VerifySopNameVo;
import com.persagy.fm.sop.service.GroupSopService;
import com.persagy.old.common.CommonConst;
import com.persagy.old.common.ToolsUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("restGroupSopService")
public class GroupSopController {

    @Autowired
    private GroupSopService groupSopService;


    /**
     * 集团sop-新增页-添加发布状态sop
     * @param saveSopVo
     * @return
     * @throws Exception
     */
    @PostMapping("/addPublishedSop")
    public FmResponseMsg addPublishedSop(@RequestBody  SaveSopVo saveSopVo) throws Exception {
        //设置查询的项目类型为集团类型的
        saveSopVo.setProject_id(CommonConst.group_sop_id);
        groupSopService.addPublishedSop(saveSopVo);
        return FmResponseUtil.successMsg("保存成功");
    }


    /**
     * 集团sop-新增页-验证sop
     * @param saveSopVo
     * @return
     * @throws Exception
     */
    @PostMapping("/verifySopBeforePublish")
    public FmResponseMsg verifySopBeforePublish(@RequestBody SaveSopVo saveSopVo) throws Exception{
        saveSopVo.setProject_id(CommonConst.group_sop_id);
        groupSopService.verifySopForPublish(saveSopVo);
        return FmResponseUtil.successMsg("验证成功");
    }

    /**
     * 集团sop-新增页-添加草稿状态sop
     * @param
     * @return
     * @throws Exception
     */
    @PostMapping("/addDraftSop")
    public String addDraftSop(@RequestBody SaveSopEditVo saveSopEditVo) throws Exception{
        String sopId = groupSopService.addDraftSop(saveSopEditVo);
        Map<String, Object> ret = new HashMap<>();
        ret.put("sop_id",sopId);
        return ToolsUtil.successJsonMsg(ret);
    }

    /**
     * 集团sop-编辑页-编辑sop时验证sop名称
     * @param verifySopNameVo
     * @return
     * @throws Exception
     */
    @PostMapping("/verifySopNameForUpdate")
    public String verifySopNameForUpdate(@RequestBody @Validated VerifySopNameVo verifySopNameVo) throws Exception{
        boolean isCan = groupSopService.verifySopBeforePublish(verifySopNameVo);
        return ToolsUtil.successJsonMsg(JSONObject.parseObject("{\"can_use\":"+isCan+"}"));

    }

    /**
     * 详细页-查询当前sop被引用的sop列表
     * @param querySopReferenceVo
     * @return
     * @throws Exception
     */

    @PostMapping("/queryReferencedSopListById")
    public String  queryReferencedSopListById(@RequestBody QuerySopReferenceVo querySopReferenceVo) throws Exception{
        List<RefSopInfo> refSopInfos = groupSopService.queryReferencedSopListById(querySopReferenceVo);
       return ToolsUtil.successJsonMsg(refSopInfos);
    }


}
